@@ -1,4 +1,4 @@
-/* electric_field.h -- This file is part of Archimedes release 0.1.1
+/* electric_field.h -- This file is part of Archimedes release 0.7.0
    Archimedes is a simulator for Submicron 2D III-V semiconductor
    Devices. It implements the Monte Carlo method and a simplfied
    version of the MEP model (Maximum Entropy Principle model)
@@ -26,7 +26,7 @@
 
 // ######################################################
 // Created on 10 Mar.2004, Siracusa, J.M.Sellier
-// Last modif. : 11 Sep.2007, Siracusa, J.M.Sellier
+// Last modif. : 21 Sep.2007, Siracusa, J.M.Sellier
 // ######################################################
 
 // Computation of the electrostatic potential,
@@ -37,7 +37,7 @@
 // the minimum energy of the semiconductor material
 // in order to take into account heterostructures.
 // For more information see the manual of 
-// GNU Archimedes release 0.1.0.
+// GNU Archimedes release 0.7.0.
 
 void 
 Electric_Field(void)
@@ -150,7 +150,7 @@ Electric_Field(void)
 // take into account heterostructures
    for(j=0;j<=ny+1;j++)
      for(i=0;i<=nx+1;i++)
-       u2d[i][j][0]=PSI[i][j]-EMIN[i_dom[i][j]][1];
+       u2d[i][j][0]-=EMIN[i_dom[i][j]][1];
 
  if(Quantum_Flag==1){
    printf("Computation of Quantum Effects\n");
